You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@river.apache.org by pe...@apache.org on 2013/01/02 06:21:08 UTC

svn commit: r1427655 [16/35] - in /river/jtsk/skunk/qa_refactor/trunk/qa: ./ doc/ src/com/sun/jini/qa/harness/ src/com/sun/jini/test/impl/discoverymanager/ src/com/sun/jini/test/impl/discoveryproviders/ src/com/sun/jini/test/impl/end2end/e2etest/ src/c...

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/AddListenerEvent.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/AddListenerEvent.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/AddListenerEvent.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/AddListenerEvent.java Wed Jan  2 05:20:52 2013
@@ -31,6 +31,7 @@ import java.rmi.RemoteException;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that bug 4712396 has been fixed. As stated in the
@@ -84,8 +85,10 @@ public class AddListenerEvent extends Ab
      *  3. Creates a template that will match the test services based on
      *     service type only
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
+        int nLookupServices = getLookupServices().getnLookupServices();
+        int nServices = getLookupServices().getnServices();
         testDesc = "" + nLookupServices + " lookup service(s), " + nServices
                  + " service(s), " + nListeners + " ServiceDiscoveryListeners";
         nAddedExpected   = nServices;
@@ -93,12 +96,13 @@ public class AddListenerEvent extends Ab
         for(int i=0;i<sdmListener.length;i++) {
             sdmListener[i] = new SDMListener(getConfig(), "", i);
         }//endloop
-    }//end setup
+        return this;
+    }//end construct
 
     /** Defines the actual steps of this particular test.
      *  
      *  1. Register the service(s) with each lookup service started during
-     *     setup.
+     *     construct.
      *  2. Create a cache that discovers the service(s), and register
      *     1 listner to receive service discovery events from that cache.
      *  3. Verifies that the expected number of serviceAdded events are sent
@@ -113,6 +117,9 @@ public class AddListenerEvent extends Ab
      */
     protected void applyTestDef() throws Exception {
 	/* Register new proxies */
+        int nServices = getLookupServices().getnServices();
+        int nAttributes = getLookupServices().getnAttributes();
+        int nSecsServiceDiscovery = getLookupServices().getnSecsServiceDiscovery();
 	registerServices(0,nServices,nAttributes,testServiceType);
 	/* Create a cache for the service that was registered; register
              * the first listener to receive service discovery events.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/DiscardDownReDiscover.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/DiscardDownReDiscover.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/DiscardDownReDiscover.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/DiscardDownReDiscover.java Wed Jan  2 05:20:52 2013
@@ -25,6 +25,7 @@ import com.sun.jini.test.share.Discovery
 import net.jini.core.lookup.ServiceItem;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 /**
@@ -60,12 +61,15 @@ public class DiscardDownReDiscover exten
      *  3. Creates a template that will match the test services based on
      *     service type only
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
+        int nLookupServices = getLookupServices().getnLookupServices();
+        int nServices = getLookupServices().getnServices();
         testDesc = "" + nLookupServices+" lookup service(s), "+nServices
                        +" service(s) -- discard down service and wait for "
                        +"re-discovery after re-registration";
-    }//end setup
+        return this;
+    }//end construct
 
     /** Defines the actual steps of this particular test.
      *  
@@ -74,6 +78,9 @@ public class DiscardDownReDiscover exten
      */
     protected void applyTestDef() throws Exception {
         super.applyTestDef();
+        int nServices = getLookupServices().getnServices();
+        int nAttributes = getLookupServices().getnAttributes();
+        int nSecsServiceDiscovery = getLookupServices().getnSecsServiceDiscovery();
 	/* Re-register the original service(s) */
 	logger.log(Level.FINE, "re-registering the original "
 		   +"services");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/DiscardServiceDown.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/DiscardServiceDown.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/DiscardServiceDown.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/DiscardServiceDown.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.servicedi
 
 import net.jini.core.lookup.ServiceItem;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 /**
@@ -54,15 +55,18 @@ public class DiscardServiceDown extends 
      *  3. Creates a template that will match the test services based on
      *     service type only
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
+        int nLookupServices = getLookupServices().getnLookupServices();
+        int nServices = getLookupServices().getnServices();
         testDesc = ""+nLookupServices+" lookup service(s), "+nServices
                        +" service(s) -- discard down service and wait for "
                        +"re-discovery";
         nAddedExpected      = 1*nServices;
         nRemovedExpected    = 1*nServices;
         simulateDownService = true;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class DiscardServiceDown
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/DiscardServiceUp.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/DiscardServiceUp.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/DiscardServiceUp.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/DiscardServiceUp.java Wed Jan  2 05:20:52 2013
@@ -30,7 +30,9 @@ import net.jini.core.lookup.ServiceItem;
 import java.rmi.RemoteException;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
+import java.util.List;
 
 /**
  * This class verifies that the <code>ServiceDiscoveryManager</code> handles
@@ -85,8 +87,10 @@ public class DiscardServiceUp extends Ab
      *  3. Creates a template that will match the test services based on
      *     service type only
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
+        int nLookupServices = getLookupServices().getnLookupServices();
+        int nServices = getLookupServices().getnServices();
         testDesc = ""+nLookupServices+" lookup service(s), "+nServices
                        +" service(s) -- discard still-up service and wait for "
                        +"re-discovery";
@@ -94,12 +98,13 @@ public class DiscardServiceUp extends Ab
         nRemovedExpected    = 1*nServices;
         simulateDownService = false;
         testServiceType     = AbstractBaseTest.TEST_SERVICE;
-    }//end setup
+        return this;
+    }//end construct
 
     /** Defines the actual steps of this particular test.
      *  
      *  1. Register the service(s) with each lookup service started during
-     *     setup.
+     *     construct.
      *  2. Create a cache that discovers the service(s), and register
      *     for service discovery events from that cache.
      *  3. Verifies the service was discovered by the cache by invoking
@@ -185,6 +190,8 @@ public class DiscardServiceUp extends Ab
      *  this situation.
      */
     protected long getAddedWait() {
+        int nLookupServices = getLookupServices().getnLookupServices();
+        int nServices = getLookupServices().getnServices();       
         long deltaWait = nServices*5*1000;
         long addedWait = (2*discardWait) + deltaWait;//1st assume not down
         if(simulateDownService) {//services down, adjust discardWait, addedWait
@@ -215,6 +222,9 @@ public class DiscardServiceUp extends Ab
      * and creates a LookupCache
      */
     protected void regServicesAndCreateCache() throws Exception {
+        int nServices = getLookupServices().getnServices();
+        int nAttributes = getLookupServices().getnAttributes();
+        int nSecsServiceDiscovery = getLookupServices().getnSecsServiceDiscovery();
         /* Register new proxies */
         registerServices(0,nServices,nAttributes,testServiceType);
         /* Create a cache for the services that were registered. */
@@ -242,6 +252,7 @@ public class DiscardServiceUp extends Ab
      * events.
      */
     protected void doServiceDiscard(ServiceItem srvcItem[]) throws Exception {
+        int nServices = getLookupServices().getnServices();
         /* Discard each service. */
         for(int i=0;i<srvcItem.length;i++) {
             logger.log(Level.FINE, "discarding service["+i+"] -- ID = "
@@ -361,6 +372,8 @@ public class DiscardServiceUp extends Ab
     protected void verifyQueryResults(ServiceItem srvcItem[],String qStr) 
 	throws Exception
     {
+        int nServices = getLookupServices().getnServices();
+        List expectedServiceList = getExpectedServiceList();
         if(srvcItem.length == 0) {
             logger.log(Level.FINE, ""+qStr+" -- no services in cache");
             throw new TestException(" -- "+qStr+" -- no services in cache");
@@ -408,7 +421,7 @@ public class DiscardServiceUp extends Ab
             logger.log(Level.FINE, ""+qStr+" -- no services in cache, as expected");
             return;
         }//endif
-
+        List expectedServiceList = getExpectedServiceList();
         for(int i=0;i<srvcItem.length;i++) {
             if(srvcItem[i].service == null) continue;
             for(int j=0;i<expectedServiceList.size();j++) {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/LookupDropProxyTaskRace.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/LookupDropProxyTaskRace.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/LookupDropProxyTaskRace.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/LookupDropProxyTaskRace.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 package com.sun.jini.test.impl.servicediscovery.event;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 import com.sun.jini.test.spec.servicediscovery.AbstractBaseTest;
@@ -126,11 +127,14 @@ public class LookupDropProxyTaskRace ext
      *  3. Creates a template that will match the test service based on
      *     service type only
      */
-    public void setup(QAConfig config) throws Exception {
+    public Test construct(QAConfig config) throws Exception {
 	// the next line used to be in the constructor. Don't see where
 	// this property is ever used
         System.setProperty( "sdm.testType", String.valueOf(thisTestType) );
-        super.setup(config);
+        super.construct(config);
+        int nLookupServices = getLookupServices().getnLookupServices();
+        int nServices = getLookupServices().getnServices();
+        int nAddServices = getLookupServices().getnAddServices();
         nAddedExpected   = nServices;
         nRemovedExpected = nAddedExpected;
         testDesc = ""+nLookupServices+" lookup service(s), "+nServices
@@ -142,7 +146,8 @@ public class LookupDropProxyTaskRace ext
                        +" serviceRemoved event(s)";
         ldm = (LookupDiscoveryManager)(srvcDiscoveryMgr.getDiscoveryManager());
         srvcListener = new SDMListener(config,"");
-    }//end setup
+        return this;
+    }//end construct
 
     /** Defines the actual steps of this particular test.
      *  
@@ -151,6 +156,9 @@ public class LookupDropProxyTaskRace ext
      *  3. Discard the lookup service to initiate the DropProxyRegTask
      */
     protected void applyTestDef() throws Exception {
+        int nLookupServices = getLookupServices().getnLookupServices();
+        int nServices = getLookupServices().getnServices();
+        int nAttributes = getLookupServices().getnAttributes();
 	logger.log(Level.FINE, "pre-register "+nServices
 		   +" service(s) with the "+nLookupServices+" lookup "
 		   +"service(s)");
@@ -202,4 +210,4 @@ public class LookupDropProxyTaskRace ext
 	}//endif
     }//end applyTestDef
 
-}//end class LookupDropProxyTaskRace
+}//end class LookupDropProxyTaskRace
\ No newline at end of file

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/LookupTaskRace.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/LookupTaskRace.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/LookupTaskRace.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/LookupTaskRace.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.servicedi
 
 import com.sun.jini.test.spec.servicediscovery.AbstractBaseTest;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.DiscoveryServiceUtil;
 
@@ -129,27 +130,34 @@ public class LookupTaskRace extends Abst
      *  3. Creates a template that will match the test service based on
      *     service type only
      */
-    public void setup(QAConfig config) throws Exception {
+    public Test construct(QAConfig config) throws Exception {
 	// from constructor, apparently never accessed
         System.setProperty( "sdm.testType", String.valueOf(thisTestType) );
-        super.setup(config);
+        super.construct(config);
+        int nLookupServices = getLookupServices().getnLookupServices();
+        int nServices = getLookupServices().getnServices();
+        int nAddServices = getLookupServices().getnAddServices();
         nAddedExpected  = nServices;
         testServiceType = AbstractBaseTest.TEST_SERVICE;
         testDesc = ": "+nLookupServices+" lookup service(s), "
                        +(nServices+nAddServices)+"service(s), should receive "
                        +nAddedExpected+" serviceAdded event(s)";
-    }//end setup
+        return this;
+    }//end construct
 
     /** Defines the actual steps of this particular test.
      *  
      *  1. Register the service with each lookup service started during
-     *     setup.
+     *     construct.
      *  2. Create a cache that discovers the service, and register
      *     for service discovery events from that cache.
      *  3. Verifies that the expected number of serviceAdded events are sent
      *     by the cache.
      */
     protected void applyTestDef() throws Exception {
+        int nServices = getLookupServices().getnServices();
+        int nAttributes = getLookupServices().getnAttributes();
+        int nSecsServiceDiscovery = getLookupServices().getnSecsServiceDiscovery();
 	/* Register new proxies */
 	registerServices(0,nServices,nAttributes,testServiceType);
 	/* Create a cache for the services that were registered. */
@@ -181,4 +189,4 @@ public class LookupTaskRace extends Abst
 	}
     }//end applyTestDef
 
-}//end class LookupTaskRace
+}//end class LookupTaskRace
\ No newline at end of file

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/LookupTaskServiceIdMapRace.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/LookupTaskServiceIdMapRace.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/NotifyEventDropProxyTaskRace.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/NotifyEventDropProxyTaskRace.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.servicedi
 
 import com.sun.jini.test.spec.servicediscovery.AbstractBaseTest;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.DiscoveryServiceUtil;
 
@@ -137,22 +138,23 @@ public class NotifyEventDropProxyTaskRac
      *  3. Creates a template that will match the test services based on
      *     service type only
      */
-    public void setup(QAConfig config)
+    public Test construct(QAConfig config)
                                                             throws Exception
     {
 	// from constructor, apparently never accessed
         System.setProperty( "sdm.testType", String.valueOf(thisTestType) );
-        super.setup(config);
-        nAddedExpected   = nAddServices;
+        super.construct(config);
+        nAddedExpected   = getnAddServices();
         nRemovedExpected = nAddedExpected;
         testServiceType  = AbstractBaseTest.TEST_SERVICE;
-        testDesc = ""+nLookupServices+" lookup service(s), "
-                       +(nServices+nAddServices)+" service(s), should receive "
+        testDesc = ""+getnLookupServices()+" lookup service(s), "
+                       +(getnServices()+getnAddServices())+" service(s), should receive "
                        +nAddedExpected+" serviceAdded and "+nRemovedExpected
                        +" serviceRemoved event(s)";
         ldm = (LookupDiscoveryManager)(srvcDiscoveryMgr.getDiscoveryManager());
         srvcListener = new SDMListener(config,"");
-    }//end setup
+        return this;
+    }//end construct
 
     /** Defines the actual steps of this particular test.
      *  
@@ -173,17 +175,17 @@ public class NotifyEventDropProxyTaskRac
 		       +" seconds for event registration to complete");
             DiscoveryServiceUtil.delayMS(nSecsRemoteCall*1000);
 	    /* kick off the NotifyEventTask/NewOldServiceTask combo */
-	    logger.log(Level.FINE, "wait over ... register "+nAddServices
+	    logger.log(Level.FINE, "wait over ... register "+getnAddServices()
 		       +" service to cause NOMATCH_MATCH to "
 		       +"initiate NotifyEventTask");
 	    registerServices
-		(nServices,nAddServices,nAttributes,testServiceType);
+		(getnServices(), getnAddServices(), getnAttributes(),testServiceType);
 	    logger.log(Level.FINE, "service registration call completed");
             logger.log(Level.FINE, 
-		       "wait "+nSecsServiceDiscovery+" seconds to allow "
+		       "wait "+getnSecsServiceDiscovery()+" seconds to allow "
 		       +"serviceAdded event(s) to arrive after service "
                        +"registration");
-            DiscoveryServiceUtil.delayMS(nSecsServiceDiscovery*1000);
+            DiscoveryServiceUtil.delayMS(getnSecsServiceDiscovery()*1000);
 	    logger.log(Level.FINE,
 		       "service(s) registered ... DISCARD lookup "
 		       +"service to initiate ProxyRegDropTask");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/ReRegisterBadEquals.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/ReRegisterBadEquals.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/ReRegisterBadEquals.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/ReRegisterBadEquals.java Wed Jan  2 05:20:52 2013
@@ -28,6 +28,7 @@ import net.jini.lookup.ServiceDiscoveryM
 
 import java.rmi.RemoteException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 /**
@@ -53,12 +54,13 @@ public class ReRegisterBadEquals extends
      *  3. Creates a template that will match the test services based on
      *     service type only
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        testDesc = ""+nLookupServices+" lookup service(s), "+nServices
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        testDesc = ""+getnLookupServices()+" lookup service(s), "+getnServices()
                        +" service(s) with poorly-defined equals() method";
         testServiceType  = AbstractBaseTest.TEST_SERVICE_BAD_EQUALS;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class ReRegisterBadEquals
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/ReRegisterGoodEquals.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/ReRegisterGoodEquals.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/ReRegisterGoodEquals.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/ReRegisterGoodEquals.java Wed Jan  2 05:20:52 2013
@@ -29,6 +29,7 @@ import net.jini.lookup.ServiceDiscoveryM
 import java.rmi.RemoteException;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 /**
@@ -65,19 +66,20 @@ public class ReRegisterGoodEquals extend
      *  3. Creates a template that will match the test services based on
      *     service type only
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        testDesc = ""+nLookupServices+" lookup service(s), "+nServices
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        testDesc = ""+getnLookupServices()+" lookup service(s), "+getnServices()
                        +" service(s) with well-defined equals() method";
-        nAddedExpected   = nServices*2;
-        nRemovedExpected = nAddedExpected-nServices;
+        nAddedExpected   = getnServices()*2;
+        nRemovedExpected = nAddedExpected-getnServices();
         testServiceType  = AbstractBaseTest.TEST_SERVICE;
-    }//end setup
+        return this;
+    }//end construct
 
     /** Defines the actual steps of this particular test.
      *  
      *  1. Register the service(s) with each lookup service started during
-     *     setup.
+     *     construct.
      *  2. Create a cache that discovers the service(s), and register
      *     for service discovery events from that cache.
      *  3. After the original services have been discovered and all expected
@@ -94,7 +96,7 @@ public class ReRegisterGoodEquals extend
      */
     protected void applyTestDef() throws Exception {
 	/* Register new proxies */
-	registerServices(0,nServices,nAttributes,testServiceType);
+	registerServices(0, getnServices(), getnAttributes(),testServiceType);
 	/* Create a cache for the services that were registered. */
 	try {
 	    logger.log(Level.FINE, "requesting a lookup cache");
@@ -109,15 +111,15 @@ public class ReRegisterGoodEquals extend
 				    +"creation");
 	}
 	logger.log(Level.FINE, "wait "
-		   +nSecsServiceDiscovery+" seconds to allow the "
+		   +getnSecsServiceDiscovery()+" seconds to allow the "
 		   +"cache to be populated ... ");
-        DiscoveryServiceUtil.delayMS(nSecsServiceDiscovery*1000);
+        DiscoveryServiceUtil.delayMS(getnSecsServiceDiscovery()*1000);
         /* Re-register new proxies */
-	reRegisterServices(0,nServices,nAttributes,testServiceType);
+	reRegisterServices(0, getnServices(), getnAttributes(),testServiceType);
 	logger.log(Level.FINE, "wait "
-		   +nSecsServiceDiscovery+" seconds to allow the "
+		   +getnSecsServiceDiscovery()+" seconds to allow the "
 		   +"cache to be re-populated ... ");
-        DiscoveryServiceUtil.delayMS(nSecsServiceDiscovery*1000);
+        DiscoveryServiceUtil.delayMS(getnSecsServiceDiscovery()*1000);
 	int nAdded   = srvcListener.getNAdded();
 	int nRemoved = srvcListener.getNRemoved();
 	logger.log(Level.FINE, "nAdded = "+nAdded

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/ServiceDiscardCacheTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/ServiceDiscardCacheTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/ServiceDiscardCacheTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/ServiceDiscardCacheTerminate.java Wed Jan  2 05:20:52 2013
@@ -25,6 +25,7 @@ import com.sun.jini.test.share.Discovery
 import net.jini.core.lookup.ServiceItem;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 /**
@@ -57,19 +58,20 @@ public class ServiceDiscardCacheTerminat
      *  3. Creates a template that will match the test services based on
      *     service type only
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
-        testDesc = ""+nLookupServices+" lookup service(s), "+nServices
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
+        testDesc = ""+getnLookupServices()+" lookup service(s), "+getnServices()
                        +" service(s) -- service discard timer task "
                        +"termination when cache is terminated";
-        nAddedExpected   = 1*nServices;
-        nRemovedExpected = 1*nServices;
-    }//end setup
+        nAddedExpected   = 1*getnServices();
+        nRemovedExpected = 1*getnServices();
+        return this;
+    }//end construct
 
     /** Defines the actual steps of this particular test.
      *  
      *  1. Register the service(s) with each lookup service started during
-     *     setup.
+     *     construct.
      *  2. Create a cache that discovers the service(s), and register
      *     for service discovery events from that cache.
      *  3. Verifies the service was discovered by the cache by invoking

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/AbstractBaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/AbstractBaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperActivateDescTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperActivateDescTest.java Wed Jan  2 05:20:52 2013
@@ -44,29 +44,29 @@ public class ActivateWrapperActivateDesc
 	logger.log(Level.INFO, "run()");
 
 	String implClassName = 
-	    config.getStringConfigVal(mailbox + ".impl", null); 
+	    getConfig().getStringConfigVal(mailbox + ".impl", null); 
 	logger.log(Level.INFO, "\timplClassName = " + implClassName);
 
 	String classpathStr =
-	    config.getStringConfigVal(mailbox + ".classpath", null)
+	    getConfig().getStringConfigVal(mailbox + ".classpath", null)
             + java.io.File.pathSeparator    			      
-            + config.getStringConfigVal(registrar + ".classpath", null); 
+            + getConfig().getStringConfigVal(registrar + ".classpath", null); 
 
 	logger.log(Level.INFO, "\tclasspath = " + classpathStr);
 	URL[] classpath = null;
 	classpath = ClassLoaderUtil.getClasspathURLs(classpathStr);
 
 	String codebase0 = 
-	    config.getStringConfigVal(registrar + ".codebase", null);
+	    getConfig().getStringConfigVal(registrar + ".codebase", null);
 	String codebase1 = 
-	    config.getStringConfigVal(mailbox + ".codebase", null);
+	    getConfig().getStringConfigVal(mailbox + ".codebase", null);
 	String codebaseStr = codebase0 + " " + codebase1;
 	logger.log(Level.INFO, "\tcodebase = " + codebaseStr);
         URL[] codebase = null;
 	codebase =  ClassLoaderUtil.getCodebaseURLs(codebaseStr);
 	
 	String policy =
-	    config.getStringConfigVal(mailbox + ".policyfile", null);
+	    getConfig().getStringConfigVal(mailbox + ".policyfile", null);
 	logger.log(Level.INFO, "\tpolicy = " + policy);
 
 	String logDir = null;

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperActivateDescTest2.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperActivateDescTest2.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperActivateDescTest2.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperActivateDescTest2.java Wed Jan  2 05:20:52 2013
@@ -49,7 +49,7 @@ public class ActivateWrapperActivateDesc
         MarshalledObject mo = new MarshalledObject(adesc);
     
         logger.log(Level.INFO, "Obtaining shared group info");
-        ActivationGroupID gid = TestUtil.loadSharedCreate(manager.getSharedVMLog());
+        ActivationGroupID gid = TestUtil.loadSharedCreate(getManager().getSharedVMLog());
     
         logger.log(Level.INFO, "Obtaining probe reference");
         ActivationID aid = 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadCodebase.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadCodebase.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadCodebase.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadCodebase.java Wed Jan  2 05:20:52 2013
@@ -54,7 +54,7 @@ public class ActivateWrapperRegisterBadC
         try {
 	    net.jini.event.EventMailbox mailbox = 
                 (net.jini.event.EventMailbox) 
-	            manager.startService("net.jini.event.EventMailbox");
+	            getManager().startService("net.jini.event.EventMailbox");
             logger.log(Level.INFO, "Created service with bogus codebase");
             throw new TestException( "ActivateWrapper.register()"
 	           + " did not throw expected exception" );

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadGroup.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadGroup.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadGroup.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadGroup.java Wed Jan  2 05:20:52 2013
@@ -43,7 +43,7 @@ public class ActivateWrapperRegisterBadG
         logger.log(Level.INFO, "run()");
         ActivateDesc adesc = 
             ActivateWrapperTestUtil.getServiceActivateDesc(
-                    "net.jini.event.EventMailbox", config);
+                    "net.jini.event.EventMailbox", getConfig());
         logger.log(Level.INFO, "EventMailbox ActivateDesc = " + adesc);
 
         logger.log(Level.INFO, "Creating activation group");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadImplClass.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadImplClass.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadImplClass.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadImplClass.java Wed Jan  2 05:20:52 2013
@@ -41,7 +41,7 @@ public class ActivateWrapperRegisterBadI
 	try { 
 	    net.jini.event.EventMailbox mailbox =
 		    (net.jini.event.EventMailbox)
-		    manager.startService("net.jini.event.EventMailbox");
+		    getManager().startService("net.jini.event.EventMailbox");
             logger.log(Level.INFO, "Created bad impl object");
             throw new TestException( "ActivateWrapper.register()"
 		    + " did not throw expected exception" );

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadStubClass.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadStubClass.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadStubClass.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadStubClass.java Wed Jan  2 05:20:52 2013
@@ -42,7 +42,7 @@ public class ActivateWrapperRegisterBadS
 	try {
 	    net.jini.event.EventMailbox mailbox =
 		    (net.jini.event.EventMailbox)
-		    manager.startService(
+		    getManager().startService(
 		    "com.sun.jini.test.impl.start.NoStubProbe");
             logger.log(Level.INFO, "Created a stub-less service");
             throw new TestException( "ActivateWrapper.register()"

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadStubCodebase.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadStubCodebase.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadStubCodebase.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterBadStubCodebase.java Wed Jan  2 05:20:52 2013
@@ -44,7 +44,7 @@ public class ActivateWrapperRegisterBadS
 	try { 
             net.jini.event.EventMailbox mailbox =
 		    (net.jini.event.EventMailbox)
-	            manager.startService("net.jini.event.EventMailbox");
+	            getManager().startService("net.jini.event.EventMailbox");
             throw new TestException( "ActivateWrapper.register()"
 				     + " did not throw expected exception" );
 	} catch (Exception ue) {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterUnsharedImpl.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterUnsharedImpl.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterUnsharedImpl.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperRegisterUnsharedImpl.java Wed Jan  2 05:20:52 2013
@@ -40,7 +40,7 @@ public class ActivateWrapperRegisterUnsh
         logger.log(Level.INFO, "run()");
 	try { 
 	    Object service =
-		    manager.startService(
+		    getManager().startService(
                     "com.sun.jini.test.impl.start.UnsharedProbe");
             logger.log(Level.INFO, "Activated unshared impl object");
             throw new TestException( "ActivateWrapper.register()"

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ClassLoaderTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ClassLoaderTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ClassLoaderTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ClassLoaderTest.java Wed Jan  2 05:20:52 2013
@@ -49,15 +49,15 @@ public class ClassLoaderTest extends Abs
 
         logger.log(Level.FINE, "activating test service 1");
 	service1 = 
-		(TestService) manager.startService(propertyKey + "1");
+		(TestService) getManager().startService(propertyKey + "1");
         logger.log(Level.FINE, "activating test service 2");
         service2 = 
-		(TestService) manager.startService(propertyKey + "2");
+		(TestService) getManager().startService(propertyKey + "2");
 
 	ActivatableServiceStarterAdmin admin1 = 
-	    (ActivatableServiceStarterAdmin) manager.getAdmin(service1);
+	    (ActivatableServiceStarterAdmin) getManager().getAdmin(service1);
 	ActivatableServiceStarterAdmin admin2 = 
-	    (ActivatableServiceStarterAdmin) manager.getAdmin(service2);
+	    (ActivatableServiceStarterAdmin) getManager().getAdmin(service2);
         if (!admin1.getGroupID().equals(admin2.getGroupID())) {
             throw new TestException("Test services have different "
                 + "ActivationGroupIDs which means that services are not "

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ClassLoaderUtilTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ClassLoaderUtilTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ClassLoaderUtilTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ClassLoaderUtilTest.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -28,7 +29,7 @@ import java.net.URL;
 import java.util.Arrays;
 import java.util.logging.Level;
 
-public class ClassLoaderUtilTest extends StarterBase {
+public class ClassLoaderUtilTest extends StarterBase implements Test {
 
     public void run() throws Exception {
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ClasspathTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ClasspathTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ClasspathTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ClasspathTest.java Wed Jan  2 05:20:52 2013
@@ -67,15 +67,15 @@ public class ClasspathTest extends Abstr
 
         logger.log(Level.FINE, "activating test service 1");
 	service1 = 
-		(TestService) manager.startService(propertyKey + "1");
+		(TestService) getManager().startService(propertyKey + "1");
         logger.log(Level.FINE, "activating test service 2");
         service2 = 
-		(TestService) manager.startService(propertyKey + "2");
+		(TestService) getManager().startService(propertyKey + "2");
 
 	ActivatableServiceStarterAdmin admin1 = 
-	    (ActivatableServiceStarterAdmin) manager.getAdmin(service1);
+	    (ActivatableServiceStarterAdmin) getManager().getAdmin(service1);
 	ActivatableServiceStarterAdmin admin2 = 
-	    (ActivatableServiceStarterAdmin) manager.getAdmin(service2);
+	    (ActivatableServiceStarterAdmin) getManager().getAdmin(service2);
 
         if (!admin1.getGroupID().equals(admin2.getGroupID())) {
             throw new TestException("Test services have different "

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/CodebaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/CodebaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/CodebaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/CodebaseTest.java Wed Jan  2 05:20:52 2013
@@ -51,15 +51,15 @@ public class CodebaseTest extends Abstra
         TestService service2 = null;
         logger.log(Level.FINE, "activating test service 1");
 	service1 = 
-		(TestService) manager.startService(propertyKey + "1");
+		(TestService) getManager().startService(propertyKey + "1");
         logger.log(Level.FINE, "activating test service 2");
 	service2 = 
-		(TestService) manager.startService(propertyKey + "2");
+		(TestService) getManager().startService(propertyKey + "2");
 
 	ActivatableServiceStarterAdmin admin1 = 
-	    (ActivatableServiceStarterAdmin) manager.getAdmin(service1);
+	    (ActivatableServiceStarterAdmin) getManager().getAdmin(service1);
 	ActivatableServiceStarterAdmin admin2 = 
-	    (ActivatableServiceStarterAdmin) manager.getAdmin(service2);
+	    (ActivatableServiceStarterAdmin) getManager().getAdmin(service2);
 
         if (!admin1.getGroupID().equals(admin2.getGroupID())) {
             throw new TestException("Test services have different "

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupCreateBadDesc.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupCreateBadDesc.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupCreateBadDesc.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupCreateBadDesc.java Wed Jan  2 05:20:52 2013
@@ -20,7 +20,7 @@ package com.sun.jini.test.impl.start;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.start.DestroySharedGroup;
 import com.sun.jini.start.ServiceDescriptor;
 import com.sun.jini.start.SharedActivatableServiceDescriptor;

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupCreateBaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupCreateBaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupCreateBaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupCreateBaseTest.java Wed Jan  2 05:20:52 2013
@@ -17,7 +17,8 @@
  */
 package com.sun.jini.test.impl.start;
 
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.start.DestroySharedGroup;
 import com.sun.jini.start.ServiceDescriptor;
 
@@ -28,7 +29,7 @@ import net.jini.config.EmptyConfiguratio
 import java.lang.reflect.Method;
 import javax.security.auth.login.LoginContext;
 
-public abstract class DestroySharedGroupCreateBaseTest extends StarterBase {
+public abstract class DestroySharedGroupCreateBaseTest extends StarterBase implements Test {
     private static final Class[] destroyArgs = 
 	new Class[] { ServiceDescriptor[].class, Configuration.class };
     private static Method destroy;

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupMainEmptyArgs.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupMainEmptyArgs.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupMainEmptyArgs.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupMainEmptyArgs.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -26,7 +27,7 @@ import net.jini.config.ConfigurationExce
 
 import java.util.Arrays;
 
-public class DestroySharedGroupMainEmptyArgs extends StarterBase {
+public class DestroySharedGroupMainEmptyArgs extends StarterBase implements Test {
     public void run() throws Exception {
 	DestroySharedGroup.main(new String[] {});
 	String[] keys = new String[] {"service.config.empty"};

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupMainEmptyConfig.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupMainEmptyConfig.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupMainEmptyConfig.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupMainEmptyConfig.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -27,7 +28,7 @@ import net.jini.config.ConfigurationExce
 import java.io.File;
 import java.util.Arrays;
 
-public class DestroySharedGroupMainEmptyConfig extends StarterBase {
+public class DestroySharedGroupMainEmptyConfig extends StarterBase implements Test {
     public void run() throws Exception {
 	File config = 
 		File.createTempFile("DestroySharedGroupMainEmptyConfig", 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupMainMissingConfig.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupMainMissingConfig.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupMainMissingConfig.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/DestroySharedGroupMainMissingConfig.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -27,7 +28,7 @@ import net.jini.config.ConfigurationExce
 import java.io.File;
 import java.util.Arrays;
 
-public class DestroySharedGroupMainMissingConfig  extends StarterBase {
+public class DestroySharedGroupMainMissingConfig  extends StarterBase implements Test {
     public void run() throws Exception {
 	File config = File.createTempFile("ServiceStarterMainMissingConfig", 
 				    ".tmp");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ExportClassLoaderTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ExportClassLoaderTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ExportClassLoaderTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ExportClassLoaderTest.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -30,7 +31,7 @@ import java.util.ArrayList;
 import java.util.Properties;
 import java.util.logging.Level;
 
-public class ExportClassLoaderTest extends StarterBase {
+public class ExportClassLoaderTest extends StarterBase implements Test {
 
     private static String importURLString = 
         "http://host:8080/service.jar http://host:8080/jsk.jar";

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/MemberGroupsProblem.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/MemberGroupsProblem.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/MemberGroupsProblem.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/MemberGroupsProblem.java Wed Jan  2 05:20:52 2013
@@ -22,6 +22,7 @@ import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.rmi.RemoteException;
 
@@ -40,10 +41,11 @@ public class MemberGroupsProblem extends
     /** Performs actions necessary to prepare for execution of the 
      *  current test.
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
 	System.setProperty("com.sun.jini.start.membergroups.problem", "true");
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/MultipleClasspathComponentTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/MultipleClasspathComponentTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/MultipleClasspathComponentTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/MultipleClasspathComponentTest.java Wed Jan  2 05:20:52 2013
@@ -26,7 +26,7 @@ import java.rmi.*;
 
 
 /**
- * Verifies that multi-component classpaths in the setup VM are
+ * Verifies that multi-component classpaths in the construct VM are
  * supported.
  */
  
@@ -35,7 +35,7 @@ public class MultipleClasspathComponentT
     public void run() throws Exception {
 	logger.log(Level.INFO, "run()");
 
-        SharedGroup group_proxy = (SharedGroup)manager.startService(
+        SharedGroup group_proxy = (SharedGroup)getManager().startService(
 		"com.sun.jini.start.SharedGroup");
     }
 }

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/NonActivatableServiceDescriptorTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/NonActivatableServiceDescriptorTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/NonActivatableServiceDescriptorTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/NonActivatableServiceDescriptorTest.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -32,7 +33,7 @@ import java.util.ArrayList;
 import java.util.Properties;
 import java.util.logging.Level;
 
-public class NonActivatableServiceDescriptorTest extends StarterBase {
+public class NonActivatableServiceDescriptorTest extends StarterBase implements Test {
 
     private static String cb = "http://host:port/cb";
     private static String p = "policy";

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/NonActivatableServiceDescriptorTest2.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/NonActivatableServiceDescriptorTest2.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/NonActivatableServiceDescriptorTest2.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/NonActivatableServiceDescriptorTest2.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -32,7 +33,7 @@ import java.util.ArrayList;
 import java.util.Properties;
 import java.util.logging.Level;
 
-public class NonActivatableServiceDescriptorTest2 extends StarterBase {
+public class NonActivatableServiceDescriptorTest2 extends StarterBase implements Test {
 
     private static String cb = "http://host:port/cb";
     private static String p = "policy";

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SecurityTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SecurityTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SecurityTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SecurityTest.java Wed Jan  2 05:20:52 2013
@@ -62,15 +62,15 @@ public class SecurityTest extends Abstra
         TestService service2 = null;
         logger.log(Level.FINE, "activating test service 1");
 	service1 = 
-		(TestService) manager.startService(propertyKey + "1");
+		(TestService) getManager().startService(propertyKey + "1");
         logger.log(Level.FINE, "activating test service 2");
 	service2 = 
-		(TestService) manager.startService(propertyKey + "2");
+		(TestService) getManager().startService(propertyKey + "2");
 
 	ActivatableServiceStarterAdmin admin1 = 
-	    (ActivatableServiceStarterAdmin) manager.getAdmin(service1);
+	    (ActivatableServiceStarterAdmin) getManager().getAdmin(service1);
 	ActivatableServiceStarterAdmin admin2 = 
-	    (ActivatableServiceStarterAdmin) manager.getAdmin(service2);
+	    (ActivatableServiceStarterAdmin) getManager().getAdmin(service2);
 
         if (!admin1.getGroupID().equals(admin2.getGroupID())) {
             throw new TestException("Test services have different "

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SecurityTestNonActivatable.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SecurityTestNonActivatable.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SecurityTestNonActivatable.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SecurityTestNonActivatable.java Wed Jan  2 05:20:52 2013
@@ -63,14 +63,14 @@ public class SecurityTestNonActivatable 
         try {
             logger.log(Level.FINE, "activating test service 1");
 	    service1 = 
-		(TestService) manager.startService(propertyKey + "1");
+		(TestService) getManager().startService(propertyKey + "1");
         } catch (RemoteException re) {
             re.printStackTrace();
         }
         try {
             logger.log(Level.FINE, "activating test service 2");
 	    service2 = 
-		(TestService) manager.startService(propertyKey + "2");
+		(TestService) getManager().startService(propertyKey + "2");
         } catch (RemoteException re) {
             re.printStackTrace();
         }

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SerializedServiceDescriptors.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SerializedServiceDescriptors.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SerializedServiceDescriptors.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SerializedServiceDescriptors.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.start.LifeCycle;
 import com.sun.jini.start.NonActivatableServiceDescriptor;
@@ -37,7 +38,7 @@ import net.jini.security.ProxyPreparer;
 
 import net.jini.config.EmptyConfiguration;
 
-public class SerializedServiceDescriptors extends StarterBase {
+public class SerializedServiceDescriptors extends StarterBase implements Test {
     private static LifeCycle lc =
 	new LifeCycle() { // default, no-op object
             public boolean unregister(Object impl) { return false; }

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceDescriptorProxyPreparationTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceDescriptorProxyPreparationTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceDescriptorProxyPreparationTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceDescriptorProxyPreparationTest.java Wed Jan  2 05:20:52 2013
@@ -43,6 +43,7 @@ import java.util.Enumeration;
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.SharedGroupAdmin;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.start.ActivateWrapper;
 import com.sun.jini.start.ActivateWrapper.ActivateDesc;
 import com.sun.jini.start.ClassLoaderUtil;
@@ -57,7 +58,7 @@ import net.jini.event.EventMailbox;
 import net.jini.security.BasicProxyPreparer;
 import net.jini.security.ProxyPreparer;
 
-public class ServiceDescriptorProxyPreparationTest extends StarterBase {
+public class ServiceDescriptorProxyPreparationTest extends StarterBase implements Test {
 
     private final RemoteException antiMercuryException = 
 	new RemoteException("Mercury service encountered");
@@ -77,9 +78,9 @@ public class ServiceDescriptorProxyPrepa
 
     public void run() throws Exception {
         SharedGroup sg = null;
-        sg = (SharedGroup)manager.startService("sharedGroup");
+        sg = (SharedGroup)getManager().startService("sharedGroup");
 	SharedGroupAdmin sga = null;
-	sga = (SharedGroupAdmin)manager.getAdmin(sg);
+	sga = (SharedGroupAdmin)getManager().getAdmin(sg);
 
         String codebase = 
             getConfig().genIntegrityCodebase(

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateActivatableNoConsServiceTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateActivatableNoConsServiceTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateActivatableNoConsServiceTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateActivatableNoConsServiceTest.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -25,7 +26,7 @@ import java.io.File;
 
 import net.jini.event.EventMailbox;
 
-public class ServiceStarterCreateActivatableNoConsServiceTest extends StarterBase {
+public class ServiceStarterCreateActivatableNoConsServiceTest extends StarterBase implements Test {
     private static String[] serviceNames = {
         "com.sun.jini.test.impl.start.TestServiceNoConsImpl"
     };
@@ -34,7 +35,7 @@ public class ServiceStarterCreateActivat
         Object service = null;
 	for (int i=0; i < serviceNames.length; i++) {
 	    try {
-		service = manager.startService(serviceNames[i]);
+		service = getManager().startService(serviceNames[i]);
                 throw new TestException(
                         "Unexpected success in creating bad service: "
 		        + serviceNames[i]);

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateActivatableServiceTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateActivatableServiceTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateActivatableServiceTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateActivatableServiceTest.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -25,7 +26,7 @@ import java.io.File;
 
 import net.jini.event.EventMailbox;
 
-public class ServiceStarterCreateActivatableServiceTest extends StarterBase {
+public class ServiceStarterCreateActivatableServiceTest extends StarterBase implements Test {
     private static String[] serviceNames = {
         "net.jini.event.EventMailbox",
         "net.jini.core.transaction.server.TransactionManager"
@@ -34,7 +35,7 @@ public class ServiceStarterCreateActivat
     public void run() throws Exception {
 	Object service = null;
 	for (int i=0; i < serviceNames.length; i++) {
-	    service = manager.startService(serviceNames[i]);
+	    service = getManager().startService(serviceNames[i]);
 	    logger.log(Level.INFO, "Created service:" + service );
 	}
         return;

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateBadServiceProxyAccessorTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateBadServiceProxyAccessorTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateBadServiceProxyAccessorTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateBadServiceProxyAccessorTest.java Wed Jan  2 05:20:52 2013
@@ -17,11 +17,12 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
 
-public class ServiceStarterCreateBadServiceProxyAccessorTest extends StarterBase {
+public class ServiceStarterCreateBadServiceProxyAccessorTest extends StarterBase implements Test {
     private static String[] serviceNames = {
         "com.sun.jini.test.impl.start.BadServiceProxyAccessorImpl"
     };
@@ -29,7 +30,7 @@ public class ServiceStarterCreateBadServ
     public void run() throws Exception {
 	Object service = null;
 	for (int i=0; i < serviceNames.length; i++) {
-	    service = manager.startService(serviceNames[i]);
+	    service = getManager().startService(serviceNames[i]);
 	    if (service != null) {
 	        logger.log(Level.INFO, "Created service:" + service );
 		throw new TestException("Created bad service: " 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateBadTransientServiceTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateBadTransientServiceTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateBadTransientServiceTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateBadTransientServiceTest.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -32,7 +33,7 @@ import java.io.FileWriter;
 import java.util.Arrays;
 import java.security.AccessControlException;
 
-public class ServiceStarterCreateBadTransientServiceTest extends StarterBase {
+public class ServiceStarterCreateBadTransientServiceTest extends StarterBase implements Test {
     public static File getServiceConfigFile() throws Exception {
         File config = File.createTempFile("Mercury", ".config");
 	config.deleteOnExit();

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateBaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateBaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateBaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateBaseTest.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.start.ServiceStarter;
 import com.sun.jini.start.ServiceDescriptor;
 
@@ -27,7 +28,7 @@ import net.jini.config.EmptyConfiguratio
 import java.lang.reflect.Method;
 import javax.security.auth.login.LoginContext;
 
-public abstract class ServiceStarterCreateBaseTest extends StarterBase {
+public abstract class ServiceStarterCreateBaseTest extends StarterBase implements Test {
     private static final Class[] createArgs = 
 	new Class[] { ServiceDescriptor[].class, Configuration.class };
     private static Method create;

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateSharedBadActServiceTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateSharedBadActServiceTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateSharedBadActServiceTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateSharedBadActServiceTest.java Wed Jan  2 05:20:52 2013
@@ -42,6 +42,7 @@ import java.util.Enumeration;
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.SharedGroupAdmin;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.start.ActivateWrapper;
 import com.sun.jini.start.ActivateWrapper.ActivateDesc;
 import com.sun.jini.start.ClassLoaderUtil;
@@ -52,12 +53,12 @@ import com.sun.jini.start.SharedActivata
 import com.sun.jini.start.SharedGroup;
 import net.jini.config.EmptyConfiguration;
 
-public class ServiceStarterCreateSharedBadActServiceTest extends StarterBase {
+public class ServiceStarterCreateSharedBadActServiceTest extends StarterBase implements Test {
     public void run() throws Exception {
         SharedGroup sg = null;
-        sg = (SharedGroup)manager.startService("sharedGroup");
+        sg = (SharedGroup)getManager().startService("sharedGroup");
 	SharedGroupAdmin sga = null;
-	sga = (SharedGroupAdmin)manager.getAdmin(sg);
+	sga = (SharedGroupAdmin)getManager().getAdmin(sg);
 
         String codebase = getConfig().getStringConfigVal(
             "net.jini.event.EventMailbox.codebase", null);

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateSharedGroupTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateSharedGroupTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateSharedGroupTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateSharedGroupTest.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import java.io.File;
@@ -40,7 +41,7 @@ import com.sun.jini.start.SharedActivati
 import com.sun.jini.system.FileSystem;
 import net.jini.config.EmptyConfiguration;
 
-public class ServiceStarterCreateSharedGroupTest extends StarterBase {
+public class ServiceStarterCreateSharedGroupTest extends StarterBase implements Test {
     public void run() throws Exception {
         String policy = getConfig().getStringConfigVal(
             "sharedGroup.policyfile", null);

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateTransientServiceTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateTransientServiceTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateTransientServiceTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterCreateTransientServiceTest.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -29,7 +30,7 @@ import java.util.Arrays;
 import net.jini.event.EventMailbox;
 import net.jini.config.EmptyConfiguration;
 
-public class ServiceStarterCreateTransientServiceTest extends StarterBase {
+public class ServiceStarterCreateTransientServiceTest extends StarterBase implements Test {
     private static String[] serviceNames = {
 	"net.jini.core.lookup.ServiceRegistrar",
 	"net.jini.discovery.LookupDiscoveryService",
@@ -41,7 +42,7 @@ public class ServiceStarterCreateTransie
     public void run() throws Exception {
         Object service = null;
 	for (int i=0; i < serviceNames.length; i++) {
-            service = manager.startService(serviceNames[i]);
+            service = getManager().startService(serviceNames[i]);
             logger.log(Level.INFO, "Created service:" + service );
 	}
         return;

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterMainEmptyArgs.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterMainEmptyArgs.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterMainEmptyArgs.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterMainEmptyArgs.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -26,7 +27,7 @@ import net.jini.config.ConfigurationExce
 
 import java.util.Arrays;
 
-public class ServiceStarterMainEmptyArgs extends StarterBase {
+public class ServiceStarterMainEmptyArgs extends StarterBase implements Test {
     public void run() throws Exception {
 	ServiceStarter.main(new String[] {});
 	String[] keys = new String[] { "service.config.empty" };

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterMainEmptyConfig.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterMainEmptyConfig.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterMainEmptyConfig.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterMainEmptyConfig.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -27,7 +28,7 @@ import net.jini.config.ConfigurationExce
 import java.io.File;
 import java.util.Arrays;
 
-public class ServiceStarterMainEmptyConfig extends StarterBase {
+public class ServiceStarterMainEmptyConfig extends StarterBase implements Test {
     public void run() throws Exception {
 	File config = 
 		File.createTempFile("ServiceStarterMainEmptyConfig", 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterMainMissingConfig.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterMainMissingConfig.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterMainMissingConfig.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ServiceStarterMainMissingConfig.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -27,7 +28,7 @@ import net.jini.config.ConfigurationExce
 import java.io.File;
 import java.util.Arrays;
 
-public class ServiceStarterMainMissingConfig extends StarterBase  {
+public class ServiceStarterMainMissingConfig extends StarterBase implements Test  {
     public void run() throws Exception {
 	File config = 
 		File.createTempFile("ServiceStarterMainMissingConfig", 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SharedActivatableServiceDescriptorTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SharedActivatableServiceDescriptorTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SharedActivatableServiceDescriptorTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SharedActivatableServiceDescriptorTest.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.start;
 import java.util.logging.Level;
 
 import com.sun.jini.action.GetIntegerAction;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.start.ServiceStarter;
 import com.sun.jini.start.SharedActivatableServiceDescriptor;
@@ -33,7 +34,7 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Properties;
 
-public class SharedActivatableServiceDescriptorTest extends StarterBase {
+public class SharedActivatableServiceDescriptorTest extends StarterBase implements Test {
 
     private static String cb = "http://host:port/cb";
     private static String pol = "policy";

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SharedActivatableServiceDescriptorTest2.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SharedActivatableServiceDescriptorTest2.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SharedActivatableServiceDescriptorTest2.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SharedActivatableServiceDescriptorTest2.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.start;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
@@ -27,7 +28,7 @@ import java.lang.reflect.Constructor;
 import java.util.Arrays;
 import java.util.Properties;
 
-public class SharedActivatableServiceDescriptorTest2 extends StarterBase {
+public class SharedActivatableServiceDescriptorTest2 extends StarterBase implements Test {
 
     private static String cb = "http://host:port/cb";
     private static String pol = "policy";

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SharedActivatableServiceDescriptorTest3.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SharedActivatableServiceDescriptorTest3.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SharedActivatableServiceDescriptorTest3.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/SharedActivatableServiceDescriptorTest3.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.impl.start;
 import java.util.logging.Level;
 
 import com.sun.jini.action.GetIntegerAction;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.start.ServiceStarter;
 import com.sun.jini.start.SharedActivatableServiceDescriptor;
@@ -33,7 +34,7 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Properties;
 
-public class SharedActivatableServiceDescriptorTest3 extends StarterBase {
+public class SharedActivatableServiceDescriptorTest3 extends StarterBase implements Test {
 
     private static String cb = "http://host:port/cb";
     private static String pol = "policy";
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/LookupTaskServiceIdMapRace.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/LookupTaskServiceIdMapRace.java Wed Jan  2 05:20:52 2013
@@ -24,6 +24,7 @@ import com.sun.jini.qa.harness.TestExcep
 import com.sun.jini.test.share.DiscoveryServiceUtil;
 
 import com.sun.jini.logging.Levels;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.discovery.LookupDiscoveryManager;
 
@@ -55,7 +56,7 @@ import java.util.logging.Level;
  * instances of NewOldServiceTask produced by NotifyEventTask when a
  * service event is received from L0.
  *
  * This test starts lookup L0 during setup. Then, when the test begins
  * running, half the services are registered with L0, followed by the
  * creation of half the SDMs and corresponding caches; which causes the
  * tasks being tested to be queued, and event generation to ultimately
@@ -228,23 +229,30 @@ public class LookupTaskServiceIdMapRace 
      *
      *  1. Start 1 (transient) lookup service
      */
-    public void setup(QAConfig config) throws Exception {
+    public Test construct(QAConfig config) throws Exception {
+        int nLookupServices = 0;
+        int nServices = 0;
+        int nAddServices = 0;
         testDesc = ""+nLookupServices+" lookup service(s), "
                        +(nServices+nAddServices)+" service(s), should receive "
                        +nAddedExpected+" serviceAdded and "+nRemovedExpected
                        +" serviceRemoved event(s)";
         testConfig = config;
 
-        createSDMInSetup = false;
+        createSDMduringConstruction = false;
         nLookupServices    = 1;
-        nAddLookupServices = 0;
-        nServices          = 0;
-        nAddServices       = 0;
-        nAttributes        = 0;
-        super.setup(config);
-
-        ldm = (LookupDiscoveryManager)(getLookupDiscoveryManager());
-    }//end setup
+        System.setProperty("net.jini.lookup.nLookupServices", Integer.toString(nLookupServices));
+//        nAddLookupServices = 0;
+//        nServices          = 0;
+//        nAddServices       = 0;
+//        nAttributes        = 0;
+        
+        super.construct(config);
+        if ( getLookupServices().getnLookupServices() != nLookupServices) 
+            throw new TestException("nLookupServices not set");
+        ldm = getLookupDiscoveryManager();
+        return this;
+    }//end construct
 
     /** Defines the actual steps of this particular test.
      *  
@@ -55,7 +56,7 @@ import java.util.logging.Level;
  * service event is received from L0.
  *
- * This test starts lookup L0 during setup. Then, when the test begins
+ * This test starts lookup L0 during construct. Then, when the test begins
  * running, half the services are registered with L0, followed by the
  * creation of half the SDMs and corresponding caches; which causes the

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/NotifyEventDropProxyTaskRace.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/servicediscovery/event/NotifyEventDropProxyTaskRace.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/AbstractBaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/AbstractBaseTest.java Wed Jan  2 05:20:52 2013
@@ -25,13 +25,14 @@ import com.sun.jini.test.share.BaseQATes
 import java.util.ArrayList;
 import java.util.Properties;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class is an abstract class that acts as the base class which
  * most, if not all, tests of the <code>ServiceStarter</code> utility
  * class should extend.
  * 
  * This class provides an implementation of the <code>setup</code> method
  * which performs standard functions related to the initialization of the
  * system state necessary to execute the test.
  *
@@ -45,9 +46,10 @@ abstract public class AbstractBaseTest e
     /** Performs actions necessary to prepare for execution of the 
      *  current test
      */
-    public void setup(QAConfig  config) throws Exception {
+    public Test construct(QAConfig  config) throws Exception {
         delayLookupStart = true;
-        super.setup(config);
+        super.construct(config);
+        return this;
     }
 }
 
@@ -25,13 +25,14 @@ import com.sun.jini.test.share.BaseQATes
  * class should extend.
  * 
- * This class provides an implementation of the <code>setup</code> method
+ * This class provides an implementation of the <code>construct</code> method
  * which performs standard functions related to the initialization of the
  * system state necessary to execute the test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/AbstractStartBaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/AbstractStartBaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/AbstractStartBaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/AbstractStartBaseTest.java Wed Jan  2 05:20:52 2013
@@ -21,7 +21,8 @@ package com.sun.jini.test.impl.start;
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class is an abstract class that acts as the base class which
@@ -29,7 +30,7 @@ import com.sun.jini.qa.harness.QATest;
  * class should extend.
  * 
  * <p>
  * This class provides an implementation of the <code>setup</code> method
  * which performs standard functions related to the initialization of the
  * system state necessary to execute the test.
  *
@@ -39,9 +40,9 @@ import com.sun.jini.qa.harness.QATest;
  * 
  *
  * @see com.sun.jini.qa.harness.QAConfig
- * @see com.sun.jini.qa.harness.QATest
+ * @see com.sun.jini.qa.harness.QATestEnvironment
  */
-abstract public class AbstractStartBaseTest extends QATest {
+abstract public class AbstractStartBaseTest extends QATestEnvironment implements Test {
 
     /** Performs actions necessary to prepare for execution of the 
      *  current test as follows:
@@ -54,16 +55,17 @@ abstract public class AbstractStartBaseT
      * The shared group is explicitly started because the harness is designed
      * to start it lazily.
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         logger.log(Level.FINE, "AbstractBaseTest:setup()");
         getSetupInfo();
 	if (config.getBooleanConfigVal("com.sun.jini.qa.harness.shared",
 				       true)) 
 	{
-	    manager.startService("sharedGroup");
+	    getManager().startService("sharedGroup");
 	}
-    }//end setup
+        return this;
+    }//end construct
 
     /* Retrieve (and display) configuration values for the current test */
     private void getSetupInfo() {
@@ -29,7 +30,7 @@ import com.sun.jini.qa.harness.QATest;
  * 
  * <p>
- * This class provides an implementation of the <code>setup</code> method
+ * This class provides an implementation of the <code>construct</code> method
  * which performs standard functions related to the initialization of the
  * system state necessary to execute the test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperActivateDescTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/start/ActivateWrapperActivateDescTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================